GpuBlendFactor enum

Blend factors.

See WebGPU spec: GPUBlendFactor.

Inheritance
Available extensions

Values

zero → const GpuBlendFactor

Factor is 0.

one → const GpuBlendFactor

Factor is 1.

src → const GpuBlendFactor

Factor is source color/alpha.

oneMinusSrc → const GpuBlendFactor

Factor is 1 - source.

srcAlpha → const GpuBlendFactor

Factor is source alpha.

oneMinusSrcAlpha → const GpuBlendFactor

Factor is 1 - source alpha.

dst → const GpuBlendFactor

Factor is destination color/alpha.

oneMinusDst → const GpuBlendFactor

Factor is 1 - destination.

dstAlpha → const GpuBlendFactor

Factor is destination alpha.

oneMinusDstAlpha → const GpuBlendFactor

Factor is 1 - destination alpha.

srcAlphaSaturated → const GpuBlendFactor

Factor is min(source alpha, 1 - destination alpha).

constant → const GpuBlendFactor

Factor is the blend constant.

oneMinusConstant → const GpuBlendFactor

Factor is 1 - blend constant.

src1 → const GpuBlendFactor

Factor is second source color/alpha. Requires "dual-source-blending".

oneMinusSrc1 → const GpuBlendFactor

Factor is 1 - second source. Requires "dual-source-blending".

src1Alpha → const GpuBlendFactor

Factor is second source alpha. Requires "dual-source-blending".

oneMinusSrc1Alpha → const GpuBlendFactor

Factor is 1 - second source alpha. Requires "dual-source-blending".

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GpuBlendFactor>
A constant List of the values in this enum, in order of their declaration.