GpuSamplerBinding class

Binds a sampler to a binding slot.

Inheritance

Constructors

GpuSamplerBinding({required int binding, required GpuSampler sampler})
Creates a sampler binding.
const

Properties

binding int
The binding index this entry corresponds to.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampler GpuSampler
The sampler to bind.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited