GpuWgslLanguageFeatureName enum
WGSL language feature names.
Values
- readonlyAndReadwriteStorageTextures → const GpuWgslLanguageFeatureName
-
Read-only and read-write storage textures.
- packed4x8IntegerDotProduct → const GpuWgslLanguageFeatureName
-
Packed 4x8 integer dot product instructions.
- unrestrictedPointerParameters → const GpuWgslLanguageFeatureName
-
Unrestricted pointer parameters in functions.
- pointerCompositeAccess → const GpuWgslLanguageFeatureName
-
Pointer composite access (member/index through pointers).
- uniformBufferStandardLayout → const GpuWgslLanguageFeatureName
-
std140 layout for uniform buffers.
- subgroupId → const GpuWgslLanguageFeatureName
-
Subgroup ID and size builtins.
- textureAndSamplerLet → const GpuWgslLanguageFeatureName
-
letdeclarations for textures and samplers. - subgroupUniformity → const GpuWgslLanguageFeatureName
-
Subgroup uniformity analysis.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GpuWgslLanguageFeatureName> - A constant List of the values in this enum, in order of their declaration.